==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.js <==
var class_ogre_1_1_static_geometry_1_1_l_o_d_bucket =
[
    [ "MaterialBucketMap", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ac66c126a9e8cace5c45cf200d17221fe", null ],
    [ "MaterialIterator", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a6240319f801ee4f58cacb9ceccd9496b", null ],
    [ "LODBucket", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a00df9c6ca5b6a3f21ff63731a543197f", null ],
    [ "~LODBucket", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a0214a1aba4c2f4c14b27ad5ef6a9c559", null ],
    [ "getParent", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#aac2688d990e29f0ec6455cdf9af54ee0", null ],
    [ "getLod", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7372f3cfd5aa8cfaf2589ad16a776ef9", null ],
    [ "getLodValue", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#acc3d9344b62bfedbc087c635e7678c95", null ],
    [ "assign", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a491d98e5031fc4db2bcb77e9c6aa3460", null ],
    [ "build", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab686c556b75f53c03cd554bd90b632c2", null ],
    [ "addRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a6244525eff9b19029642e262a1cee216", null ],
    [ "getMaterialBuckets", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a0976b3b23f4040b2694723da8218e894", null ],
    [ "getMaterialIterator", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab772c6af3bb6cf79a5f6bb3bb3d84aaa", null ],
    [ "dump", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a3f360a28a8a1a27e0baf86142be8ffe0", null ],
    [ "visitRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#abb4929bf76d5e7a3b70297cf74965aaf", null ],
    [ "getEdgeList", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7b7d8789e819a72862a56918c17f94e1", null ],
    [ "getShadowRenderableList", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a2a895595891f3a7332382d86939bd962", null ],
    [ "isVertexProgramInUse", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a9928b782916e2739a62accca185e6a48", null ],
    [ "updateShadowRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab907eb21b0f40634427fee3e9e82adb5", null ]
];

==> ogre-14.3.2-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.js <==
var class_ogre_1_1_static_geometry_1_1_l_o_d_bucket =
[
    [ "MaterialBucketMap", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7e285ae7eefce3be51a64bdfcc62d697", null ],
    [ "MaterialIterator", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#adbab94d8dbba62da8e63739fd5cc76a1", null ],
    [ "LODBucket", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a00df9c6ca5b6a3f21ff63731a543197f", null ],
    [ "~LODBucket", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a0214a1aba4c2f4c14b27ad5ef6a9c559", null ],
    [ "getParent", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#aac2688d990e29f0ec6455cdf9af54ee0", null ],
    [ "getLod", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7372f3cfd5aa8cfaf2589ad16a776ef9", null ],
    [ "getLodValue", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#acc3d9344b62bfedbc087c635e7678c95", null ],
    [ "assign", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a491d98e5031fc4db2bcb77e9c6aa3460", null ],
    [ "build", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab686c556b75f53c03cd554bd90b632c2", null ],
    [ "addRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a6244525eff9b19029642e262a1cee216", null ],
    [ "getMaterialBuckets", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a0976b3b23f4040b2694723da8218e894", null ],
    [ "getMaterialIterator", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab772c6af3bb6cf79a5f6bb3bb3d84aaa", null ],
    [ "visitRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#abb4929bf76d5e7a3b70297cf74965aaf", null ],
    [ "getEdgeList", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a7b7d8789e819a72862a56918c17f94e1", null ],
    [ "getShadowRenderableList", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a2a895595891f3a7332382d86939bd962", null ],
    [ "isVertexProgramInUse", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a9928b782916e2739a62accca185e6a48", null ],
    [ "updateShadowRenderables", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#ab907eb21b0f40634427fee3e9e82adb5", null ],
    [ "operator<<", "class_ogre_1_1_static_geometry_1_1_l_o_d_bucket.html#a42a8380d57d91d8aea32e552d88cfa6a", null ]
];
